@@ -25,27 +25,27 @@ import sys
 
 def id2filename(fileid):
     """Algorithm for getting filepath from an integer id."""
-    hexfileid = '{0:x}'.format(fileid)
-    directories = ''
+    hexfileid = "{0:x}".format(fileid)
+    directories = ""
     while len(hexfileid) > 2:
-        directories = '{0}/{1}'.format(directories, hexfileid[-2:])
+        directories = "{0}/{1}".format(directories, hexfileid[-2:])
         hexfileid = hexfileid[:-2]
-    if directories == '':
-        filename = 'file.{0}'.format(hexfileid)
-        filepath = '/{0}'.format(filename)
-        directories = '/'
+    if directories == "":
+        filename = "file.{0}".format(hexfileid)
+        filepath = "/{0}".format(filename)
+        directories = "/"
     else:
-        filename = '{0:x}'.format(fileid)
-        filepath = '{0}/{1}'.format(directories, filename)
+        filename = "{0:x}".format(fileid)
+        filepath = "{0}/{1}".format(directories, filename)
     return filepath
 
 
 def filename2id(path):
     """Convert a filepath to and ID."""
-    if path[:6] == '/file.':
+    if path[:6] == "/file.":
         return int(path[6:], 16)
-    return int(path.split('/')[-1], 16)
+    return int(path.split("/")[-1], 16)
 
 
-if __name__ == '__main__':  # pragma: no cover
+if __name__ == "__main__":  # pragma: no cover
     print(id2filename(int(sys.argv[1])))
